@@ -3,6 +3,8 @@ import os
 from typing import Dict, Optional, Any
 from kaizen.llms.prompts.general_prompts import BASIC_SYSTEM_PROMPT
 from kaizen.utils.config import ConfigData
+from kaizen.helpers.general import retry
+from kaizen.helpers.parser import extract_json
 from litellm import Router
 import logging
 
@@ -123,6 +125,25 @@ class LLMProvider:
         )
         return response["choices"][0]["message"]["content"], response["usage"]
 
+    @retry(max_attempts=3, delay=1)
+    def chat_completion_with_json(
+        self,
+        prompt,
+        user: str = None,
+        model="default",
+        custom_model=None,
+        messages=None,
+    ):
+        response, usage = self.chat_completion(
+            prompt=prompt,
+            user=user,
+            model=model,
+            custom_model=custom_model,
+            messages=messages,
+        )
+        response = extract_json(response)
+        return response, usage
+
     def is_inside_token_limit(self, PROMPT: str, percentage: float = 0.8) -> bool:
         # Include system prompt in token calculation
         messages = [
