@@ -7,6 +7,7 @@ from kaizen.llms.prompts.code_review_prompts import (
     CODE_REVIEW_PROMPT,
     FILE_CODE_REVIEW_PROMPT,
     PR_REVIEW_EVALUATION_PROMPT,
+    CODE_REVIEW_SYSTEM_PROMPT,
 )
 
 
@@ -22,6 +23,7 @@ class CodeReviewer:
     def __init__(self, llm_provider: LLMProvider):
         self.logger = logging.getLogger(__name__)
         self.provider = llm_provider
+        self.provider.system_prompt = CODE_REVIEW_SYSTEM_PROMPT
 
     def is_code_review_prompt_within_limit(
         self,
@@ -51,6 +53,8 @@ class CodeReviewer:
             CODE_DIFF=diff_text,
         )
         total_usage = {"prompt_tokens": 0, "completion_tokens": 0, "total_tokens": 0}
+        if not diff_text and not pull_request_files:
+            raise Exception("Both diff_text and pull_request_files are empty!")
 
         if self.provider.is_inside_token_limit(PROMPT=prompt):
             reviews = self._process_full_diff(
@@ -86,14 +90,12 @@ class CodeReviewer:
         total_usage: Dict[str, int],
     ) -> List[Dict]:
         self.logger.debug("Processing directly from diff")
-        resp, usage = self.provider.chat_completion(prompt, user=user)
+        resp, usage = self.provider.chat_completion_with_json(prompt, user=user)
         total_usage = self.provider.update_usage(total_usage, usage)
 
         if reeval_response:
             resp = self._reevaluate_response(prompt, resp, user, total_usage)
-
-        review_json = parser.extract_json(resp)
-        return review_json["review"]
+        return resp["review"]
 
     def _process_files(
         self,
@@ -182,14 +184,13 @@ class CodeReviewer:
             PULL_REQUEST_DESC=pull_request_desc,
             FILE_PATCH=diff_data,
         )
-        resp, usage = self.provider.chat_completion(prompt, user=user)
+        resp, usage = self.provider.chat_completion_with_json(prompt, user=user)
         total_usage = self.provider.update_usage(total_usage, usage)
 
         if reeval_response:
             resp = self._reevaluate_response(prompt, resp, user, total_usage)
 
-        review_json = parser.extract_json(resp)
-        return review_json["review"]
+        return resp["review"]
 
     def _reevaluate_response(
         self, prompt: str, resp: str, user: Optional[str], total_usage: Dict[str, int]
